@@ -5,9 +5,9 @@
 ###
 ### Gaussian spatial interaction function for twinstim's epidemic component
 ###
-### Copyright (C) 2009-2013 Sebastian Meyer
-### $Revision: 638 $
-### $Date: 2013-09-03 16:59:05 +0200 (Die, 03 Sep 2013) $
+### Copyright (C) 2009-2014 Sebastian Meyer
+### $Revision: 771 $
+### $Date: 2014-02-17 10:52:54 +0100 (Mon, 17. Feb 2014) $
 ################################################################################
 
 
@@ -34,10 +34,15 @@ siaf.gaussian <- function (nTypes = 1, logsd = TRUE, density = FALSE,
 {
     nTypes <- as.integer(nTypes)
     stopifnot(length(nTypes) == 1L, nTypes > 0L)
+    if (isScalar(F.adaptive)) {
+        adapt <- F.adaptive
+        F.adaptive <- TRUE
+    } else adapt <- 0.1
 
     f <- function (s, pars, types) {}       # coordinate matrix s, length(types) = 1 or nrow(s)
     F <- if (F.adaptive) {
-        function(polydomain, f, pars, type, adapt=0.1) {}
+        as.function(c(alist(polydomain=, f=, pars=, type=),
+                      list(adapt=adapt), quote({})))
     } else siaf.fallback.F
     Fcircle <- function (r, pars, type) {}  # single radius and type
     effRange <- function (pars) {}
@@ -78,7 +83,7 @@ siaf.gaussian <- function (nTypes = 1, logsd = TRUE, density = FALSE,
             tmp1, tmp1.1,
             expression(
                 eps <- adapt * sd,
-                intf <- polyCub::polyCub.midpoint(polydomain, f, pars, type, eps=eps),
+                intf <- polyCub.midpoint(polydomain, f, pars, type, eps=eps),
                 intf
                 )
         ))
@@ -103,15 +108,15 @@ siaf.gaussian <- function (nTypes = 1, logsd = TRUE, density = FALSE,
     # derivative of f wrt pars
     derivexpr <- if (logsd) { # derive f wrt psi=log(sd) !!
         if (density) {
-            quote(deriv[cbind(1:L,colidx)] <- exp(-frac) / pi/sdss^2 * (frac-1))
+            quote(deriv[cbind(seq_len(L),colidx)] <- exp(-frac) / pi/sdss^2 * (frac-1))
         } else {
-            quote(deriv[cbind(1:L,colidx)] <- exp(-frac) * 2*frac)
+            quote(deriv[cbind(seq_len(L),colidx)] <- exp(-frac) * 2*frac)
         }
     } else { # derive f wrt sd !!
         if (density) {
-            quote(deriv[cbind(1:L,colidx)] <- exp(-frac) / pi/sdss^3 * (frac-1))
+            quote(deriv[cbind(seq_len(L),colidx)] <- exp(-frac) / pi/sdss^3 * (frac-1))
         } else {
-            quote(deriv[cbind(1:L,colidx)] <- exp(-frac) * 2*frac/sdss)
+            quote(deriv[cbind(seq_len(L),colidx)] <- exp(-frac) * 2*frac/sdss)
         }
     }
     derivexpr <- do.call("substitute", args=list(expr=derivexpr,
@@ -145,7 +150,7 @@ siaf.gaussian <- function (nTypes = 1, logsd = TRUE, density = FALSE,
         } else { # d f(s|type_i) / d sigma_{type_j} is 0 for i != j
             expression(deriv.type <- function (s) deriv(s, pars, type)[,type,drop=TRUE])
         },
-        expression(int <- polyCub::polyCub.SV(polydomain, deriv.type, nGQ=nGQ, alpha=a)),
+        expression(int <- polyCub.SV(polydomain, deriv.type, nGQ=nGQ, alpha=a)),
         if (nTypes == 1L) expression(int) else expression(
             res <- numeric(length(pars)), # zeros
             res[type] <- int,
